@@ -126,7 +126,7 @@ test_that("SI, 2G, CL: 2 sim", {
 test_that("SI, 1G, OP: 1 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25,
-                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
+                     a.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
   init <- init.icm(s.num = 500, i.num = 1)
   control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = FALSE)
   x <- icm(param, init, control)
@@ -149,7 +149,7 @@ test_that("SI, 1G, OP: 1 sim", {
 test_that("SI, 1G, OP: 2 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25,
-                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
+                     a.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
   init <- init.icm(s.num = 500, i.num = 1)
   control <- control.icm(type = "SI", nsteps = 50, nsims = 2, verbose = FALSE)
   x <- icm(param, init, control)
@@ -173,7 +173,7 @@ test_that("SI, 1G, OP: 2 sim", {
 test_that("SI, 2G, OP: 1 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
-                     balance = "g1", b.rate = 1/100, b.rate.g2 = NA,
+                     balance = "g1", a.rate = 1/100, a.rate.g2 = NA,
                      ds.rate = 1/100, ds.rate.g2 = 1/100,
                      di.rate = 1/90, di.rate.g2 = 1/90)
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
@@ -198,7 +198,7 @@ test_that("SI, 2G, OP: 1 sim", {
 test_that("SI, 2G, OP: 2 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
-                     balance = "g1", b.rate = 1/100, b.rate.g2 = NA,
+                     balance = "g1", a.rate = 1/100, a.rate.g2 = NA,
                      ds.rate = 1/100, ds.rate.g2 = 1/100,
                      di.rate = 1/90, di.rate.g2 = 1/90)
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
@@ -347,7 +347,7 @@ test_that("SIR, 2G, CL: 2 sim", {
 test_that("SIR, 1G, OP: 1 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 3, rec.rate = 1/50,
-                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90,
+                     a.rate = 1/100, ds.rate = 1/100, di.rate = 1/90,
                      dr.rate = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
   control <- control.icm(type = "SIR", nsteps = 100, nsims = 1, verbose = FALSE)
@@ -371,11 +371,11 @@ test_that("SIR, 1G, OP: 1 sim", {
 test_that("SIR, 1G, OP: 2 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 3, rec.rate = 1/50,
-                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90,
+                     a.rate = 1/100, ds.rate = 1/100, di.rate = 1/90,
                      dr.rate = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
   control <- control.icm(type = "SIR", nsteps = 50, nsims = 2, verbose = FALSE,
-                         d.rand = FALSE, b.rand = FALSE)
+                         d.rand = FALSE, a.rand = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -398,7 +398,7 @@ test_that("SIR, 2G, OP: 1 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, inf.prob.g2 = 0.1, act.rate = 3,
                      balance = "g1", rec.rate = 1/50, rec.rate.g2 = 1/50,
-                     b.rate = 1/100, b.rate.g2 = NA, ds.rate = 1/100,
+                     a.rate = 1/100, a.rate.g2 = NA, ds.rate = 1/100,
                      ds.rate.g2 = 1/100, di.rate = 1/90, di.rate.g2 = 1/90,
                      dr.rate = 1/100, dr.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0,
@@ -426,13 +426,13 @@ test_that("SIR, 2G, OP: 2 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, inf.prob.g2 = 0.1, act.rate = 3,
                      balance = "g1", rec.rate = 1/50, rec.rate.g2 = 1/50,
-                     b.rate = 1/100, b.rate.g2 = NA, ds.rate = 1/100,
+                     a.rate = 1/100, a.rate.g2 = NA, ds.rate = 1/100,
                      ds.rate.g2 = 1/100, di.rate = 1/90, di.rate.g2 = 1/90,
                      dr.rate = 1/100, dr.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0,
                    s.num.g2 = 500, i.num.g2 = 0, r.num.g2 = 0)
   control <- control.icm(type = "SIR", nsteps = 50, nsims = 2, verbose = FALSE,
-                         verbose.int = 1, d.rand = FALSE, b.rand = FALSE)
+                         verbose.int = 1, d.rand = FALSE, a.rand = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -572,7 +572,7 @@ test_that("SIS, 2G, CL: 2 sim", {
 test_that("SIS, 1G, OP: 1 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.5, rec.rate = 1/50,
-                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
+                     a.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
   init <- init.icm(s.num = 500, i.num = 1)
   control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = FALSE)
   x <- icm(param, init, control)
@@ -595,7 +595,7 @@ test_that("SIS, 1G, OP: 1 sim", {
 test_that("SIS, 1G, OP: 2 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.5, rec.rate = 1/50,
-                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
+                     a.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
   init <- init.icm(s.num = 500, i.num = 1)
   control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = FALSE)
   x <- icm(param, init, control)
@@ -620,7 +620,7 @@ test_that("SIS, 2G, OP: 1 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, inf.prob.g2 = 0.1, act.rate = 0.5,
                      balance = "g1", rec.rate = 1/50, rec.rate.g2 = 1/50,
-                     b.rate = 1/100, b.rate.g2 = NA, ds.rate = 1/100,
+                     a.rate = 1/100, a.rate.g2 = NA, ds.rate = 1/100,
                      ds.rate.g2 = 1/100, di.rate = 1/90, di.rate.g2 = 1/90)
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 1)
   control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = FALSE)
@@ -644,7 +644,7 @@ test_that("SIS, 2G, OP: 2 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, inf.prob.g2 = 0.1, act.rate = 0.5,
                      balance = "g1", rec.rate = 1/50, rec.rate.g2 = 1/50,
-                     b.rate = 1/100, b.rate.g2 = NA, ds.rate = 1/100,
+                     a.rate = 1/100, a.rate.g2 = NA, ds.rate = 1/100,
                      ds.rate.g2 = 1/100, di.rate = 1/90, di.rate.g2 = 1/90)
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 1)
   control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = FALSE,
